=======
Changes
=======

0.3
===

 - Add Django 2.0 compatibility
 - Extract ``MediaDefiningClass`` base class from ``MediaDefiningView``

0.2
===

 - Specify different requirements in ``setup.py`` based on the current Python version
 - Allow to use inline JavaScript in media definitions (wrap with ``<script>`` tag)

0.1
===

 - Initial release
